#target Illustrator

/* This is a script for Adobe Illustrator that will clear the current swatch palette
   and replace it with the 325-color palette developed by Comico, the Comic Company.
   It's possible to generate other palettes by modifying the code below. I just knocked
   this code together in an afternoon; it's not intended to be anything other than a quick
   tool for generating palettes. This code is public domain and is free for your use under 
   NO WARRANTY, either expressed or implied.
   Author: Neil McAllister <neil@neilmcallister.com>  9 July, 2011
*/

// This array holds the screen percent values for each step in the chart.
// If you want to generate the 64-color palette, for example, delete the 70 value.
// Changing the 70 to a 75 will switch from 70% screens to 75% screens for each color.
var screenValue = [ 0, 25, 50, 70, 100 ];
// These are the values for the color codes. They match the percentage values above.
// Therefore, if you delete the 70 from the above array, you must delete the "4" from
// This array, also.
var screenCode = [ "", "2", "3", "4", "" ];

if( app.documents.length > 0) {
	var newColor = new CMYKColor;
	newColor.black = 0;
	newColor.cyan = 0;
	newColor.yellow = 0;
	var c, m, y, colorName;
	app.activeDocument.swatchGroups.removeAll();
	// These nested loops step through each of the colors in order
	for( y=0; y<screenValue.length; y++ ) {
		for( c=0; c<screenValue.length; c++ ) {
			for( m=0; m<screenValue.length; m++ ) {
				// This last loop is for the three black values in the Comico chart.
				// Delete this loop and the switch statement below if you will not be
				// using any black screens (for any chart but the Comico chart)
				for( k=0; k<3; k++ ) {
						newSwatch = app.activeDocument.swatches.add();
						newColor.cyan = screenValue[c];
						newColor.magenta = screenValue[m];
						newColor.yellow = screenValue[y];
						colorName = "";
						// 
						if( y>0 ) {
							colorName = colorName + "Y" + screenCode[y];
						}
						if( m>0 ) {
							colorName = colorName + "R" + screenCode[m];
						}
						if( c>0 ) {
							colorName = colorName + "B" + screenCode[c];
						}
						// This is a special case for the three black values, since
						// they don't follow the same conventions as the other colors.
						// Delete this block if you don't want any black screens.
						switch(k) {
							case 0:
								newColor.black = 0;
								break;
							case 1:
								newColor.black = 10;
								colorName = colorName + "K1";
								break;
							case 2:
								newColor.black = 20;
								colorName = colorName + "K2";
								break;
						}
						newSwatch.color = newColor;
						newSwatch.name = colorName;
				}
			}
		}
	}
	app.activeDocument.swatches[0].name = "White";
	// Note that this script does not save the swatch library for you; you must do that yourself.
}